listBlockedTCPPorts abstract method

Future<Set<int>> listBlockedTCPPorts({
  1. bool sudo = false,
  2. Set<int>? allowedPorts,
})

Lists all the currently blocked TCP ports.

  • sudo: A flag indicating if sudo privileges should be used. Defaults to false.
  • allowedPorts: A set of allowed ports, or null to allow all ports.

Returns a Future that completes with a Set of blocked TCP ports.

Implementation

Future<Set<int>> listBlockedTCPPorts(
    {bool sudo = false, Set<int>? allowedPorts});