loginErrorLimit property
The maximum number of consecutive login errors allowed before blocking the remote address.
Implementation
final int loginErrorLimit;
The maximum number of consecutive login errors allowed before blocking the remote address.
final int loginErrorLimit;