gatekeeper library
Gatekeeper - Network Port Manager
Classes
- Gatekeeper
- The Gatekeeper class manages TCP port access by interfacing with the GatekeeperDriver. It provides functionality to list, block, and unblock TCP ports with optional permission checks and sudo privileges.
- GatekeeperDriver
- The GatekeeperDriver class is an abstract class that defines the contract for interacting with the system to manage TCP port access, resolve binary paths, and run commands.