listBlockedTCPPorts abstract method
Lists all the currently blocked TCP ports.
sudo: A flag indicating if sudo privileges should be used. Defaults tofalse.allowedPorts: A set of allowed ports, ornullto allow all ports.
Returns a Future that completes with a Set of blocked TCP ports.
Implementation
Future<Set<int>> listBlockedTCPPorts(
{bool sudo = false, Set<int>? allowedPorts});