resolve method
Resolves this GatekeeperDriver instance to ensure that it can be used in this system.
Returns a Future that completes with a bool indicating success or failure.
Implementation
@override
Future<bool> resolve() async {
final iptablesBin = await resolveBinaryPathCached('iptables');
return iptablesBin.isNotEmpty;
}